'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

/**
 * Returns the text value of a rich text document.
 *
 * Note that this can also be applied to any block node of a structured text
 * document.
 */
function documentToPlainTextString(nodeList, blockDivisor) {
    if (blockDivisor === void 0) { blockDivisor = ' '; }
    /**
     * Algorithm notes: We only want to apply spacing when a node is part of a
     * sequence. This is tricky because nodes can often be deeply nested within
     * non-semantic content arrays. For example, to get the text value of an
     * unordered list, we have to traverse like so:
     *
     * {
     *   nodeType: BLOCKS.UL_LIST,
     *   content: [
     *     {
     *       nodeType: BLOCKS.LIST_ITEM,
     *       content: [{
     *         nodeType: BLOCKS.PARAGRAPH,
     *         content: [
     *           { nodeType: 'text', value: 'List ', marks: [] },
     *           { nodeType: 'text', value: 'item', marks: [{ type: 'bold' }] }
     *         ]
     *       }]
     *     },
     *     {
     *       nodeType: BLOCKS.OL_LIST,
     *       content: [{
     *         nodeType: BLOCKS.PARAGRAPH,
     *         content: [
     *           { nodeType: 'text', value: 'Another list item', marks: [] }
     *         ]
     *       }]
     *     },
     *     {
     *       nodeType: BLOCKS.HR,
     *       data: {},
     *       content: [],
     *     },
     *     {
     *       nodeType: BLOCKS.OL_LIST,
     *       content: [{
     *         nodeType: BLOCKS.PARAGRAPH,
     *         content: [
     *           { nodeType: 'text', value: 'Yet another list item', marks: [] }
     *         ]
     *       }]
     *     },
     *   }]
     * }
     *
     * We want there to be a space between 'List item' and 'Another list item' (to
     * denote a visual line break, which conventionally appears between non-text
     * node sequences) but not a redundant space between 'List ' and 'item'.
     * Moreover, we want just a _singular_ space between 'Another list item' and
     * 'Yet another list item' - the non-semantic HR between the two nodes should
     * not denote an additional space.
     */
    return nodeList.content.reduce(function (textValue, node, i) {
        var nodeIsText = isText(node);
        var nodeTextValue = nodeIsText
            ? node.value
            : documentToPlainTextString(node);
        if (!nodeIsText && !nodeTextValue.length) {
            return textValue;
        }
        else {
            var nextNode = nodeList.content[i + 1];
            var nodeIsInBlockSequence = nextNode && !isText(nextNode);
            var divisor = nodeIsInBlockSequence ? blockDivisor : '';
            return textValue + nodeTextValue + divisor;
        }
    }, '');
}
function isText(node) {
    return node.nodeType === 'text';
}

exports.documentToPlainTextString = documentToPlainTextString;
//# sourceMappingURL=rich-text-plain-text-renderer--demo.es5.js.map
